@@ -47,9 +47,10 @@ function (model, digits, ...)
     on.exit(options(warn = o.warn))
     options(warn = -1)
     for (i in seq_len(x$k.f)[x$not.na]) {
-        res <- try(rma(x$yi.f[-i], x$vi.f[-i], weights = x$weights.f[-i], 
-            mods = cbind(x$X.f[-i, ]), method = x$method, weighted = x$weighted, 
-            intercept = FALSE, knha = x$knha, control = x$control), 
+        res <- try(suppressWarnings(rma(x$yi.f[-i], x$vi.f[-i], 
+            weights = x$weights.f[-i], mods = cbind(x$X.f[-i, 
+                ]), method = x$method, weighted = x$weighted, 
+            intercept = FALSE, knha = x$knha, control = x$control)), 
             silent = TRUE)
         if (inherits(res, "try-error")) 
             next
