@@ -30,16 +30,16 @@ function (x, digits, transf, targs, ...)
     QEp <- rep(NA_real_, x$k.f)
     for (i in seq_len(x$k.f)[x$not.na]) {
         if (is.element(x$measure, c("RR", "OR", "RD"))) {
-            res <- try(rma.mh(ai = x$ai.f[-i], bi = x$bi.f[-i], 
-                ci = x$ci.f[-i], di = x$di.f[-i], measure = x$measure, 
-                add = x$add, to = x$to, drop00 = x$drop00, correct = x$correct), 
-                silent = TRUE)
+            res <- try(suppressWarnings(rma.mh(ai = x$ai.f[-i], 
+                bi = x$bi.f[-i], ci = x$ci.f[-i], di = x$di.f[-i], 
+                measure = x$measure, add = x$add, to = x$to, 
+                drop00 = x$drop00, correct = x$correct)), silent = TRUE)
         }
         else {
-            res <- try(rma.mh(x1i = x$x1i.f[-i], x2i = x$x2i.f[-i], 
-                t1i = x$t1i.f[-i], t2i = x$t2i.f[-i], measure = x$measure, 
-                add = x$add, to = x$to, drop00 = x$drop00, correct = x$correct), 
-                silent = TRUE)
+            res <- try(suppressWarnings(rma.mh(x1i = x$x1i.f[-i], 
+                x2i = x$x2i.f[-i], t1i = x$t1i.f[-i], t2i = x$t2i.f[-i], 
+                measure = x$measure, add = x$add, to = x$to, 
+                drop00 = x$drop00, correct = x$correct)), silent = TRUE)
         }
         if (inherits(res, "try-error")) 
             next
