@@ -10,12 +10,14 @@ function (x, digits, ...)
         res.fixed <- formatC(x$fixed, digits = digits, format = "f")
         print(res.fixed, quote = FALSE, right = TRUE)
     }
-    if (names(x)[1] == "random" || names(x)[2] == "random") {
+    if (is.element("random", names(x))) {
         if (names(x)[1] == "fixed") 
             cat("\n")
         res.random <- formatC(x$random, digits = digits, format = "f")
+        res.random[, 2] <- paste0(x$lb.sign, res.random[, 2])
+        res.random[, 3] <- paste0(x$ub.sign, res.random[, 3])
         print(res.random, quote = FALSE, right = TRUE)
-        if (is.na(x$random[1, 2]) && is.na(x$random[1, 3])) 
+        if (x$ci.null) 
             message("\nThe upper and lower CI bounds for tau^2 both fall below ", 
                 x$tau2.min, ".\nThe CIs are therefore equal to the null/empty set.", 
                 sep = "")
