@@ -130,11 +130,11 @@ function (x, digits, showfit = FALSE, signif.stars = getOption("show.signif.star
     if (x$p > 1) {
         cat("Test of Moderators (coefficient(s) ", paste(x$btt, 
             collapse = ","), "): \n", sep = "")
-        if (x$knha || x$robust) {
-            cat("F(df1 = ", x$m, ", df2 = ", x$k - x$p, ") = ", 
-                formatC(x$QM, digits = digits, format = "f"), 
-                ", p-val ", .pval(x$QMp, digits = digits, showeq = TRUE, 
-                  sep = " "), "\n\n", sep = "")
+        if (x$knha) {
+            cat("F(df1 = ", x$m, ", df2 = ", x$dfs, ") = ", formatC(x$QM, 
+                digits = digits, format = "f"), ", p-val ", .pval(x$QMp, 
+                digits = digits, showeq = TRUE, sep = " "), "\n\n", 
+                sep = "")
         }
         else {
             cat("QM(df = ", x$m, ") = ", formatC(x$QM, digits = digits, 
@@ -145,7 +145,7 @@ function (x, digits, showfit = FALSE, signif.stars = getOption("show.signif.star
     if (x$int.only) {
         res.table <- c(estimate = x$b, se = x$se, zval = x$zval, 
             pval = x$pval, ci.lb = x$ci.lb, ci.ub = x$ci.ub)
-        if (x$knha || x$robust) 
+        if (x$knha) 
             names(res.table)[3] <- "tval"
         res.table <- formatC(res.table, digits = digits, format = "f")
         signif <- symnum(x$pval, corr = FALSE, na = FALSE, cutpoints = c(0, 
@@ -167,7 +167,7 @@ function (x, digits, showfit = FALSE, signif.stars = getOption("show.signif.star
             pval = x$pval, ci.lb = x$ci.lb, ci.ub = x$ci.ub)
         colnames(res.table) <- c("estimate", "se", "zval", "pval", 
             "ci.lb", "ci.ub")
-        if (x$knha || x$robust) 
+        if (x$knha) 
             colnames(res.table)[3] <- "tval"
         signif <- symnum(x$pval, corr = FALSE, na = FALSE, cutpoints = c(0, 
             0.001, 0.01, 0.05, 0.1, 1), symbols = c("***", "**", 
