@@ -72,8 +72,6 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         else {
             if (anyNA(slab)) 
                 stop("NAs in study labels.")
-            if (anyDuplicated(slab) > 0) 
-                slab <- make.unique(slab)
             if (length(slab) != k) 
                 stop("Study labels not of same length as data.")
             slab.null <- FALSE
@@ -90,6 +88,8 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
             ids <- ids[subset]
             k <- length(ai)
         }
+        if (anyDuplicated(slab)) 
+            slab <- make.unique(as.character(slab))
         dat <- escalc(measure = measure, ai = ai, bi = bi, ci = ci, 
             di = di, add = add[1], to = to[1], drop00 = drop00[1])
         yi <- dat$yi
@@ -111,11 +111,11 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         vi.f <- vi
         ni.f <- ni
         k.f <- k
-        aibicidi.na <- is.na(cbind(ai, bi, ci, di))
+        aibicidi.na <- is.na(ai) | is.na(bi) | is.na(ci) | is.na(di)
         if (any(aibicidi.na)) {
             if (verbose) 
                 message("Handling NAs in table data ...")
-            not.na <- rowSums(aibicidi.na) == 0L
+            not.na <- !aibicidi.na
             if (na.act == "na.omit" || na.act == "na.exclude" || 
                 na.act == "na.pass") {
                 ai <- ai[not.na]
@@ -133,11 +133,11 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         }
         if (k < 1) 
             stop("Processing terminated since k = 0.")
-        yivi.na <- is.na(cbind(yi, vi))
+        yivi.na <- is.na(yi) | is.na(vi)
         if (any(yivi.na)) {
             if (verbose) 
                 message("Handling NAs in yi/vi ...")
-            not.na.yivi <- rowSums(yivi.na) == 0L
+            not.na.yivi <- !yivi.na
             if (na.act == "na.omit" || na.act == "na.exclude" || 
                 na.act == "na.pass") {
                 yi <- yi[not.na.yivi]
@@ -202,8 +202,6 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         else {
             if (anyNA(slab)) 
                 stop("NAs in study labels.")
-            if (anyDuplicated(slab) > 0) 
-                slab <- make.unique(slab)
             if (length(slab) != k) 
                 stop("Study labels not of same length as data.")
             slab.null <- FALSE
@@ -220,6 +218,8 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
             ids <- ids[subset]
             k <- length(x1i)
         }
+        if (anyDuplicated(slab)) 
+            slab <- make.unique(as.character(slab))
         dat <- escalc(measure = measure, x1i = x1i, x2i = x2i, 
             t1i = t1i, t2i = t2i, add = add[1], to = to[1], drop00 = drop00[1])
         yi <- dat$yi
@@ -238,11 +238,12 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         vi.f <- vi
         ni.f <- ni
         k.f <- k
-        x1ix2it1it2i.na <- is.na(cbind(x1i, x2i, t1i, t2i))
+        x1ix2it1it2i.na <- is.na(x1i) | is.na(x2i) | is.na(t1i) | 
+            is.na(t2i)
         if (any(x1ix2it1it2i.na)) {
             if (verbose) 
                 message("Handling NAs in table data ...")
-            not.na <- rowSums(x1ix2it1it2i.na) == 0L
+            not.na <- !x1ix2it1it2i.na
             if (na.act == "na.omit" || na.act == "na.exclude" || 
                 na.act == "na.pass") {
                 x1i <- x1i[not.na]
@@ -260,11 +261,11 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         }
         if (k < 1) 
             stop("Processing terminated since k = 0.")
-        yivi.na <- is.na(cbind(yi, vi))
+        yivi.na <- is.na(yi) | is.na(vi)
         if (any(yivi.na)) {
             if (verbose) 
                 message("Handling NAs in yi/vi ...")
-            not.na.yivi <- rowSums(yivi.na) == 0L
+            not.na.yivi <- !yivi.na
             if (na.act == "na.omit" || na.act == "na.exclude" || 
                 na.act == "na.pass") {
                 yi <- yi[not.na.yivi]
@@ -527,7 +528,7 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
     method <- "FE"
     weighted <- TRUE
     knha <- FALSE
-    robust <- FALSE
+    dfs <- NA
     res <- list(b = b, se = se, zval = zval, pval = pval, ci.lb = ci.lb, 
         ci.ub = ci.ub, vb = vb, tau2 = tau2, k = k, k.f = k.f, 
         k.yi = k.yi, k.pos = k.pos, k.eff = k.eff, p = p, parms = parms, 
@@ -540,9 +541,9 @@ function (ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure = "OR",
         t2i.f = t2i.f, ni = ni, ni.f = ni.f, ids = ids, not.na = not.na, 
         not.na.yivi = not.na.yivi, slab = slab, slab.null = slab.null, 
         measure = measure, method = method, weighted = weighted, 
-        knha = knha, robust = robust, intercept = intercept, 
-        digits = digits, level = level, add = add, to = to, drop00 = drop00, 
-        correct = correct, fit.stats = fit.stats, version = packageVersion("metafor"), 
+        knha = knha, dfs = dfs, intercept = intercept, digits = digits, 
+        level = level, add = add, to = to, drop00 = drop00, correct = correct, 
+        fit.stats = fit.stats, version = packageVersion("metafor"), 
         call = mf)
     class(res) <- c("rma.mh", "rma")
     return(res)
