@@ -54,7 +54,7 @@ test_that("results are correct for the two-level random-effects model fitted wit
 test_that("results are correct for the three-level random-effects model fitted with rma.mv() using ML estimation.", {
 
    ### three-level model (ml = multilevel parameterization)
-   res.ml <- rma.mv(yi, vi, random = list(~ 1 | district, ~ 1 | study), data=dat, method="ML")
+   res.ml <- rma.mv(yi, vi, random = ~ 1 | district/study, data=dat, method="ML")
 
    ### compare with results on page 71 (Table 5)
    expect_equivalent(round(coef(res.ml),3), 0.184)
@@ -66,7 +66,7 @@ test_that("results are correct for the three-level random-effects model fitted w
 test_that("results are correct for the three-level mixed-effects model fitted with rma.mv() using ML estimation.", {
 
    ### three-level model (multilevel parameterization)
-   res.ml <- rma.mv(yi, vi, mods = ~ I(year-mean(year)), random = list(~ 1 | district, ~ 1 | study), data=dat, method="ML")
+   res.ml <- rma.mv(yi, vi, mods = ~ I(year-mean(year)), random = ~ 1 | district/study, data=dat, method="ML")
 
    ### compare with results on page 71 (Table 5)
    expect_equivalent(round(coef(res.ml),3), c(0.178, 0.005)) ### intercept is given as 0.183 in paper, but this seems to be a misprint
@@ -78,7 +78,7 @@ test_that("results are correct for the three-level mixed-effects model fitted wi
 test_that("results are correct for the three-level random-effects model fitted with rma.mv() using REML estimation.", {
 
    ### three-level model (ml = multilevel parameterization)
-   res.ml <- rma.mv(yi, vi, random = list(~ 1 | district, ~ 1 | study), data=dat)
+   res.ml <- rma.mv(yi, vi, random = ~ 1 | district/study, data=dat)
 
    ### (results for this not given in paper)
    expect_equivalent(round(coef(res.ml),3), 0.185)
@@ -96,12 +96,12 @@ test_that("results are correct for the three-level random-effects model fitted w
 
 })
 
-test_that("profiling works for the three-level random-effects model (multilevel parameterization(.", {
+test_that("profiling works for the three-level random-effects model (multilevel parameterization).", {
 
    skip_on_cran()
 
    ### three-level model (ml = multilevel parameterization)
-   res.ml <- rma.mv(yi, vi, random = list(~ 1 | district, ~ 1 | study), data=dat)
+   res.ml <- rma.mv(yi, vi, random = ~ 1 | district/study, data=dat)
 
    ### profile variance components
    par(mfrow=c(2,1))
