@@ -12,11 +12,11 @@ test_that("rma() handles NAs correctly.", {
 
    res <- rma(yi, vi, data=dat, digits=3)
 
-   expect_that(res$k, equals(11))
-   expect_that(res$k.f, equals(13))
-   expect_that(length(res$yi), equals(11))
-   expect_that(length(res$yi.f), equals(13))
-   expect_that(res$not.na, equals(rep(c(FALSE,TRUE),times=c(2,11))))
+   expect_equivalent(res$k, 11)
+   expect_equivalent(res$k.f, 13)
+   expect_equivalent(length(res$yi), 11)
+   expect_equivalent(length(res$yi.f), 13)
+   expect_equivalent(res$not.na, rep(c(FALSE,TRUE),times=c(2,11)))
 
    dat$ablat[3] <- NA
 
